summaryrefslogtreecommitdiffstats
path: root/compiler/rustc_middle/src/mir/query.rs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/rustc_middle/src/mir/query.rs')
-rw-r--r--compiler/rustc_middle/src/mir/query.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/compiler/rustc_middle/src/mir/query.rs b/compiler/rustc_middle/src/mir/query.rs
index 613b132ff..71bec49af 100644
--- a/compiler/rustc_middle/src/mir/query.rs
+++ b/compiler/rustc_middle/src/mir/query.rs
@@ -194,11 +194,11 @@ impl Debug for GeneratorLayout<'_> {
}
impl Debug for GenVariantPrinter {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
- let variant_name = ty::GeneratorSubsts::variant_name(self.0);
+ let variant_name = ty::GeneratorArgs::variant_name(self.0);
if fmt.alternate() {
write!(fmt, "{:9}({:?})", variant_name, self.0)
} else {
- write!(fmt, "{}", variant_name)
+ write!(fmt, "{variant_name}")
}
}
}
@@ -265,10 +265,10 @@ pub struct ConstQualifs {
/// `UniversalRegions::closure_mapping`.) Note the free regions in the
/// closure's signature and captures are erased.
///
/// Example: If type check produces a closure with the closure substs:
///
/// ```text
-/// ClosureSubsts = [
+/// ClosureArgs = [
/// 'a, // From the parent.
/// 'b,
/// i8, // the "closure kind"
@@ -280,7 +280,7 @@ pub struct ConstQualifs {
/// We would "renumber" each free region to a unique vid, as follows:
///
/// ```text
-/// ClosureSubsts = [
+/// ClosureArgs = [
/// '1, // From the parent.
/// '2,
/// i8, // the "closure kind"
@@ -265,10 +265,10 @@ pub struct ConstQualifs {
/// closure's signature and captures are erased.
///
-/// Example: If type check produces a closure with the closure substs:
+/// Example: If type check produces a closure with the closure args:
///
/// ```text